# 🌀 blue_options

🌀 `blue_options` implements an `options` for Bash.

```bash
pip install blue_options
```

wip 🔥

---

[![PyPI version](https://img.shields.io/pypi/v/blue_options.svg)](https://pypi.org/project/blue_options/)
